pub enum EasyShipShipmentStatus {
Show 16 variants
PendingSchedule,
PendingPickUp,
PendingDropOff,
LabelCanceled,
PickedUp,
DroppedOff,
AtOriginFC,
AtDestinationFC,
Delivered,
RejectedByBuyer,
Undeliverable,
ReturningToSeller,
ReturnedToSeller,
Lost,
OutForDelivery,
Damaged,
}Expand description
EasyShipShipmentStatus : The status of the Amazon Easy Ship order. This property is included only for Amazon Easy Ship orders. The status of the Amazon Easy Ship order. This property is included only for Amazon Easy Ship orders.
Variants
PendingSchedule
PendingPickUp
PendingDropOff
LabelCanceled
PickedUp
DroppedOff
AtOriginFC
AtDestinationFC
Delivered
RejectedByBuyer
Undeliverable
ReturningToSeller
ReturnedToSeller
Lost
OutForDelivery
Damaged